searchData={"items":[{"type":"module","title":"MpesaElixir.API","doc":"HTTP client for interacting with the M-Pesa API.\n\nThis module provides a lightweight wrapper around the Req HTTP client,\nspecifically configured for making requests to the Safaricom M-Pesa API.\nIt handles authentication, request formatting, and environment-specific\nbase URLs.","ref":"MpesaElixir.API.html"},{"type":"module","title":"Features - MpesaElixir.API","doc":"- Automatic bearer token authentication\n- JSON request body encoding\n- Content-type header management\n- Environment-aware base URL selection (sandbox vs production)\n- Simplified request interface","ref":"MpesaElixir.API.html#module-features"},{"type":"module","title":"Examples - MpesaElixir.API","doc":"```elixir\n# Simple request to an M-Pesa endpoint\nMpesaElixir.API.request(\"/mpesa/stkpush/v1/processrequest\",\n  body: %{\n    BusinessShortCode: \"174379\",\n    Password: \"MTc0Mzc5YmZiMjc5ZjlhYTliZGJjZjE1OGU5N2RkNzFhNDY3Y2QyZTBjODkzMDU5YjEwZjc4ZTZiNzJhZGExZWQyYzkxOTIwMjAwMjE2MTY1NjI4\",\n    Timestamp: \"20200216165628\",\n    TransactionType: \"CustomerPayBillOnline\",\n    Amount: 1,\n    PartyA: \"254712345678\",\n    PartyB: \"174379\",\n    PhoneNumber: \"254712345678\",\n    CallBackURL: \"https://example.com/callback\",\n    AccountReference: \"Test\",\n    TransactionDesc: \"Test\"\n  }\n)\n\n# Creating a customized client for multiple requests\nclient = MpesaElixir.API.new(\n  base_url: \"https://custom-mpesa-proxy.example.com\",\n  retry: [max_attempts: 3]\n)\n\nReq.post(client, url: \"/some/endpoint\", body: %{key: \"value\"})\n```","ref":"MpesaElixir.API.html#module-examples"},{"type":"module","title":"Configuration - MpesaElixir.API","doc":"Configure the environment in your application config:\n\n```elixir\n# For sandbox environment\nconfig :mpesa_elixir, sandbox: true\n\n# For production environment\nconfig :mpesa_elixir, sandbox: false\n```","ref":"MpesaElixir.API.html#module-configuration"},{"type":"function","title":"MpesaElixir.API.handle_response/1","doc":"","ref":"MpesaElixir.API.html#handle_response/1"},{"type":"function","title":"MpesaElixir.API.new/1","doc":"","ref":"MpesaElixir.API.html#new/1"},{"type":"behaviour","title":"MpesaElixir.API.Behaviour","doc":"Defines the behavior for the MpesaElixir.API module.\n\nThis module defines the callback functions that must be implemented\nby modules that handle HTTP requests to the M-Pesa API.\n\nThe primary purpose is to provide an interface for mocking during tests.","ref":"MpesaElixir.API.Behaviour.html"},{"type":"callback","title":"MpesaElixir.API.Behaviour.request/2","doc":"","ref":"MpesaElixir.API.Behaviour.html#c:request/2"},{"type":"module","title":"MpesaElixir.AuthServer","doc":"A GenServer implementation that manages Mpesa API authentication tokens.\n\nThis server is responsible for:\n\n1. Obtaining an access token from the Mpesa API during initialization\n2. Storing the token in an ETS table for quick access\n3. Automatically refreshing the token before it expires\n4. Providing a function to retrieve the current token","ref":"MpesaElixir.AuthServer.html"},{"type":"module","title":"Usage - MpesaElixir.AuthServer","doc":"The AuthServer should be added to your application's supervision tree:\n\n```elixir\nchildren = [\n  # ... other children\n  MpesaElixir.AuthServer\n]\n\nSupervisor.start_link(children, strategy: :one_for_one)\n```\n\nYou can then retrieve the current access token when needed:\n\n```elixir\ntoken = MpesaElixir.AuthServer.get_token()\n```","ref":"MpesaElixir.AuthServer.html#module-usage"},{"type":"module","title":"Configuration - MpesaElixir.AuthServer","doc":"The server requires the following configuration parameters:\n\n```elixir\nconfig :mpesa_elixir,\n  consumer_key: \"your_consumer_key\",\n  consumer_secret: \"your_consumer_secret\"\n```","ref":"MpesaElixir.AuthServer.html#module-configuration"},{"type":"module","title":"Implementation details - MpesaElixir.AuthServer","doc":"- Uses ETS for token storage, with a named table `:token_store`\n- Automatically refreshes tokens 100 seconds before expiration\n- Terminates with an error if token retrieval fails","ref":"MpesaElixir.AuthServer.html#module-implementation-details"},{"type":"function","title":"MpesaElixir.AuthServer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MpesaElixir.AuthServer.html#child_spec/1"},{"type":"function","title":"MpesaElixir.AuthServer.get_token/0","doc":"","ref":"MpesaElixir.AuthServer.html#get_token/0"},{"type":"function","title":"MpesaElixir.AuthServer.start_link/1","doc":"","ref":"MpesaElixir.AuthServer.html#start_link/1"},{"type":"module","title":"MpesaElixir.C2b","doc":"Provides functionality for integrating with Safaricom's M-PESA Customer to Business (C2B) API.\nThis module enables businesses to receive payments from customers directly to their M-PESA accounts\nthrough register_urls functionality that configures callback URLs for payment notifications.\n\nC2B allows businesses to register validation and confirmation URLs that receive real-time\nnotification of payments made to their paybill or till numbers, enabling automated payment\nprocessing and reconciliation.","ref":"MpesaElixir.C2b.html"},{"type":"function","title":"MpesaElixir.C2b.register_urls/1","doc":"Registers callback URLs for M-PESA C2B payment notifications.\n\nThis function configures the validation and confirmation URLs that will receive real-time\nnotifications when customers make payments to your paybill or till number. These URLs must be\npublicly accessible HTTPS endpoints that can receive and process the payment data.","ref":"MpesaElixir.C2b.html#register_urls/1"},{"type":"function","title":"Parameters - MpesaElixir.C2b.register_urls/1","doc":"* `request` - A `RegisterRequest` struct containing:\n  * `short_code` - Your M-PESA till or paybill number\n  * `response_type` - The type of response expected:\n    * `\"Completed\"` - Payments are automatically completed after confirmation\n    * `\"Cancelled\"` - Payments may be validated before completion\n  * `confirmation_url` - The HTTPS URL that receives payment confirmation data\n  * `validation_url` - The HTTPS URL that receives payment validation requests","ref":"MpesaElixir.C2b.html#register_urls/1-parameters"},{"type":"function","title":"Response - MpesaElixir.C2b.register_urls/1","doc":"Returns `{:ok, response}` on success where `response` is a map containing:\n* `\"ConversationID\"` - A unique identifier for the API request\n* `\"OriginatorCoversationID\"` - A unique identifier for the transaction\n* `\"ResponseDescription\"` - A description of the operation result\n\nReturns `{:error, reason}` on failure.","ref":"MpesaElixir.C2b.html#register_urls/1-response"},{"type":"function","title":"Examples - MpesaElixir.C2b.register_urls/1","doc":"iex> request = %MpesaElixir.C2b.RegisterRequest{\n    ...>   short_code: \"600000\",\n    ...>   response_type: \"Completed\",\n    ...>   confirmation_url: \"https://example.com/mpesa/confirmation\",\n    ...>   validation_url: \"https://example.com/mpesa/validation\"\n    ...> }\n    iex> MpesaElixir.C2b.register_urls(request)\n    {:ok, %{\n      \"ConversationID\" => \"AG_20230815_1234567890abcdef\",\n      \"OriginatorCoversationID\" => \"12345-67890-1\",\n      \"ResponseDescription\" => \"Success. Request accepted for processing\"\n    }}","ref":"MpesaElixir.C2b.html#register_urls/1-examples"},{"type":"function","title":"Notes - MpesaElixir.C2b.register_urls/1","doc":"* Both URLs must be secure (HTTPS) and publicly accessible\n* The validation URL receives requests before payment completion and can accept/reject them\n* The confirmation URL receives notification after a successful payment\n* Response type \"Completed\" is recommended for most use cases to simplify the payment flow\n* If your URLs change, you need to re-register them using this API\n* The endpoints will receive JSON payloads with transaction details","ref":"MpesaElixir.C2b.html#register_urls/1-notes"},{"type":"module","title":"MpesaElixir.C2b.RegisterRequest","doc":"","ref":"MpesaElixir.C2b.RegisterRequest.html"},{"type":"type","title":"MpesaElixir.C2b.RegisterRequest.t/0","doc":"","ref":"MpesaElixir.C2b.RegisterRequest.html#t:t/0"},{"type":"module","title":"MpesaElixir.QrCode.Request","doc":"","ref":"MpesaElixir.QrCode.Request.html"},{"type":"type","title":"MpesaElixir.QrCode.Request.t/0","doc":"","ref":"MpesaElixir.QrCode.Request.html#t:t/0"},{"type":"module","title":"MpesaElixir.StkPush","doc":"Provides functionality for initiating M-Pesa STK Push requests.\n\nThe STK Push (also known as Lipa na M-PESA online or Network Initiated push)\nallows merchants to initiate C2B (Customer to Business) payments by sending\na payment prompt to a customer's M-PESA registered phone number.\n\nThis module handles the creation and submission of STK Push requests to the\nM-Pesa API, managing authentication details and proper formatting of the request.","ref":"MpesaElixir.StkPush.html"},{"type":"module","title":"How it works - MpesaElixir.StkPush","doc":"1. The merchant captures necessary parameters and sends an API request\n2. M-Pesa validates the request and sends an acknowledgment\n3. An STK Push prompt is sent to the customer's phone\n4. Customer confirms by entering their M-PESA PIN\n5. M-Pesa processes the transaction (validating PIN, debiting customer, crediting merchant)\n6. Results are sent back via the specified callback URL\n7. Customer receives an SMS confirmation","ref":"MpesaElixir.StkPush.html#module-how-it-works"},{"type":"module","title":"Example - MpesaElixir.StkPush","doc":"alias MpesaElixir.StkPush\n    alias MpesaElixir.StkPush.Request\n\n    request = Request.new(%{\n      business_short_code: \"174379\",\n      transaction_type: \"CustomerPayBillOnline\",\n      amount: \"100\",\n      party_a: \"254712345678\",\n      party_b: \"174379\",\n      phone_number: \"254712345678\",\n      call_back_url: \"https://mydomain.com/callback\",\n      account_reference: \"Payment for order #1234\",\n      transaction_desc: \"Order payment\"\n    })\n\n    case StkPush.request(request) do\n      {:ok, response} ->\n        # Handle successful request submission\n        # The response contains MerchantRequestID and CheckoutRequestID\n        # Final transaction results will be sent to the callback URL\n      {:error, reason} ->\n        # Handle error\n    end","ref":"MpesaElixir.StkPush.html#module-example"},{"type":"function","title":"MpesaElixir.StkPush.query_stk_push_status/1","doc":"","ref":"MpesaElixir.StkPush.html#query_stk_push_status/1"},{"type":"function","title":"MpesaElixir.StkPush.request/1","doc":"Initiates an STK Push request to the M-Pesa API.\n\nThis function takes a `Request` struct, automatically generates the password\nand timestamp if they are not provided, and sends the request to the M-Pesa API.\n\nThe password is generated using the formula: Base64(BusinessShortCode + PassKey + Timestamp)\nwhere PassKey is configured in the application environment.","ref":"MpesaElixir.StkPush.html#request/1"},{"type":"function","title":"Parameters - MpesaElixir.StkPush.request/1","doc":"* `request` - A `MpesaElixir.StkPush.Request` struct containing all required parameters","ref":"MpesaElixir.StkPush.html#request/1-parameters"},{"type":"function","title":"Returns - MpesaElixir.StkPush.request/1","doc":"* `{:ok, response}` - On successful submission, returns the API response containing\n    MerchantRequestID and CheckoutRequestID\n  * `{:error, reason}` - If the request fails","ref":"MpesaElixir.StkPush.html#request/1-returns"},{"type":"function","title":"Example - MpesaElixir.StkPush.request/1","doc":"request = MpesaElixir.StkPush.Request.new(%{\n      business_short_code: \"174379\",\n      transaction_type: \"CustomerPayBillOnline\",\n      amount: \"100\",\n      party_a: \"254712345678\",\n      party_b: \"174379\",\n      phone_number: \"254712345678\",\n      call_back_url: \"https://mydomain.com/callback\",\n      account_reference: \"Order #1234\",\n      transaction_desc: \"Order payment\"\n    })\n\n    MpesaElixir.StkPush.request(request)","ref":"MpesaElixir.StkPush.html#request/1-example"},{"type":"module","title":"MpesaElixir.StkPush.Request","doc":"Represents a request body for the Lipa na M-PESA online API (STK Push).\n\nThis struct contains all the required parameters for initiating a C2B payment\nthrough M-PESA's STK Push service, which sends a payment prompt to the\ncustomer's phone.","ref":"MpesaElixir.StkPush.Request.html"},{"type":"function","title":"MpesaElixir.StkPush.Request.new/1","doc":"Creates a new STK Push request with the provided parameters.","ref":"MpesaElixir.StkPush.Request.html#new/1"},{"type":"function","title":"Examples - MpesaElixir.StkPush.Request.new/1","doc":"iex> MpesaElixir.StkPush.Request.new(%{\n    ...>   business_short_code: \"174379\",\n    ...>   password: \"MTc0Mzc5YmZiMjc5ZjlhYTliZGJjZjE1OGU5N2RkNzFhNDY3Y2QyZTBjODkzMDU5YjEwZjc4ZTZiNzJhZGExZWQyYzkxOTIwMTYwMjE2MTY1NjI3\",\n    ...>   timestamp: \"20160216165627\",\n    ...>   transaction_type: \"CustomerPayBillOnline\",\n    ...>   amount: \"1\",\n    ...>   party_a: \"254708374149\",\n    ...>   party_b: \"174379\",\n    ...>   phone_number: \"254708374149\",\n    ...>   call_back_url: \"https://mydomain.com/path\",\n    ...>   account_reference: \"Test\",\n    ...>   transaction_desc: \"Test\"\n    ...> })","ref":"MpesaElixir.StkPush.Request.html#new/1-examples"},{"type":"type","title":"MpesaElixir.StkPush.Request.t/0","doc":"STK Push request parameters","ref":"MpesaElixir.StkPush.Request.html#t:t/0"},{"type":"function","title":"MpesaElixir.StkPush.Request.to_api_map/1","doc":"Converts the struct to a map with keys formatted as required by the M-PESA API.\nThis function transforms snake_case field names to PascalCase as expected by the API.\n\nwill set the password and timestamp if they are not provided.","ref":"MpesaElixir.StkPush.Request.html#to_api_map/1"},{"type":"function","title":"Examples - MpesaElixir.StkPush.Request.to_api_map/1","doc":"iex> request = %MpesaElixir.StkPush.Request{\n    ...>   business_short_code: \"174379\",\n    ...>   password: \"MTc0Mzc5YmZiMjc5ZjlhYTliZGJjZjE1OGU5N2RkNzFhNDY3Y2QyZTBjODkzMDU5YjEwZjc4ZTZiNzJhZGExZWQyYzkxOTIwMTYwMjE2MTY1NjI3\",\n    ...>   timestamp: \"20160216165627\",\n    ...>   transaction_type: \"CustomerPayBillOnline\",\n    ...>   amount: \"1\",\n    ...>   party_a: \"254708374149\",\n    ...>   party_b: \"174379\",\n    ...>   phone_number: \"254708374149\",\n    ...>   call_back_url: \"https://mydomain.com/path\",\n    ...>   account_reference: \"Test\",\n    ...>   transaction_desc: \"Test\"\n    ...> }\n    iex> MpesaElixir.StkPush.Request.to_api_map(request)\n    %{\n      \"BusinessShortCode\" => \"174379\",\n      \"Password\" => \"MTc0Mzc5YmZiMjc5ZjlhYTliZGJjZjE1OGU5N2RkNzFhNDY3Y2QyZTBjODkzMDU5YjEwZjc4ZTZiNzJhZGExZWQyYzkxOTIwMTYwMjE2MTY1NjI3\",\n      \"Timestamp\" => \"20160216165627\",\n      \"TransactionType\" => \"CustomerPayBillOnline\",\n      \"Amount\" => \"1\",\n      \"PartyA\" => \"254708374149\",\n      \"PartyB\" => \"174379\",\n      \"PhoneNumber\" => \"254708374149\",\n      \"CallBackURL\" => \"https://mydomain.com/path\",\n      \"AccountReference\" => \"Test\",\n      \"TransactionDesc\" => \"Test\"\n    }","ref":"MpesaElixir.StkPush.Request.html#to_api_map/1-examples"},{"type":"module","title":"MpesaElixir.Utils","doc":"Utility functions for the MpesaElixir application.","ref":"MpesaElixir.Utils.html"},{"type":"function","title":"MpesaElixir.Utils.capitalize/2","doc":"","ref":"MpesaElixir.Utils.html#capitalize/2"},{"type":"function","title":"MpesaElixir.Utils.generate_password/3","doc":"Generates the base64 encoded password string from shortcode, passkey and timestamp.","ref":"MpesaElixir.Utils.html#generate_password/3"},{"type":"function","title":"Examples - MpesaElixir.Utils.generate_password/3","doc":"iex> MPesa.StkPush.Request.generate_password(\"174379\", \"bfb279f9aa9bdbcf158e97dd71a467cd2e0c89305\", \"20160216165627\")\n    \"MTc0Mzc5YmZiMjc5ZjlhYTliZGJjZjE1OGU5N2RkNzFhNDY3Y2QyZTBjODkzMDU5YjEwZjc4ZTZiNzJhZGExZWQyYzkxOTIwMTYwMjE2MTY1NjI3\"","ref":"MpesaElixir.Utils.html#generate_password/3-examples"},{"type":"function","title":"MpesaElixir.Utils.generate_timestamp/0","doc":"Generates a timestamp in the format YYYYMMDDHHMMSS.\nThe timestamp is generated based on the current UTC time, adjusted by 3 hours (Nairobi Timezone).","ref":"MpesaElixir.Utils.html#generate_timestamp/0"},{"type":"function","title":"MpesaElixir.Utils.to_api_map/2","doc":"Converts a struct to a map with keys formatted as required by the M-PESA API.\nThis function transforms snake_case field names to PascalCase as expected by the API.","ref":"MpesaElixir.Utils.html#to_api_map/2"},{"type":"function","title":"Examples - MpesaElixir.Utils.to_api_map/2","doc":"iex> request = %MpesaElixir.StkPush.Request{\n    ...>   business_short_code: \"174379\",\n    ...>   password: \"MTc0Mzc5YmZiMjc5ZjlhYTliZGJjZjE1OGU5N2RkNzFhNDY3Y2QyZTBjODkzMDU5YjEwZjc4ZTZiNzJhZGExZWQyYzkxOTIwMTYwMjE2MTY1NjI3\",\n    ...>   timestamp: \"20160216165627\",\n    ...>   transaction_type: \"CustomerPayBillOnline\",\n    ...>   amount: \"1\",\n    ...>   party_a: \"254708374149\",\n    ...>   party_b: \"174379\",\n    ...>   phone_number: \"254708374149\",\n    ...>   call_back_url: \"https://mydomain.com/path\",\n    ...>   account_reference: \"Test\",\n    ...>   transaction_desc: \"Test\"\n    ...> }\n    iex> MpesaElixir.Utils.to_api_map(request, special_cases: [\"url\"])","ref":"MpesaElixir.Utils.html#to_api_map/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}